@@ -1,5 +1,10 @@
 #!/bin/bash
 
+if [ "x$EDITOR" = "x" ];
+then
+        EDITOR=vi
+fi
+
 if [ "x$1" = "x-f"  ]
 then
     autoscan
@@ -12,6 +17,6 @@ fi
 ### použít jen když je třeba použít configure.h.in
 #autoheader
 
-aclocal
-automake -a -c
-autoconf
+aclocal \
+&& automake -a -c \
+&& autoconf
